@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Aspect::Library ();
 
-our $VERSION = '0.981';
+our $VERSION = '0.983';
 our @ISA     = 'Aspect::Library';
 
 sub new {
@@ -48,17 +48,6 @@ sub get_advice {
 
 
 
-######################################################################
-# Back Compatibility
-
-BEGIN {
-	*params = *args;
-}
-
-
-
-
-
 ######################################################################
 # Optional XS Acceleration
 
